@@ -6,12 +6,13 @@ import requests
 import sys
 from feagi_agent_freenove.Led import *
 from feagi_agent_freenove.PCA9685 import PCA9685
-from feagi_agent_freenove.configuration import *
+from feagi_agent_freenove.configuration import  *
 from picamera import PiCamera
 from datetime import datetime
 from collections import deque
 from picamera.array import PiRGBArray
 
+
 runtime_data = {
     "current_burst_id": 0,
     "feagi_state": None,
@@ -417,10 +418,11 @@ def main():
     runtime_data["feagi_state"] = FEAGI.feagi_registration(feagi_host=feagi_host,
                                                            api_port=api_port, agent_settings=agent_settings,
                                                            capabilities=capabilities)
-    ipu_channel_address = FEAGI.feagi_inbound(agent_settings["agent_data_port"])
+    ipu_channel_address = FEAGI.feagi_outbound(feagi_settings['feagi_host'],
+                                               agent_settings["agent_data_port"])
     opu_channel_address = FEAGI.feagi_outbound(feagi_settings['feagi_host'],
                                                runtime_data["feagi_state"]['feagi_opu_port'])
-    feagi_ipu_channel = FEAGI.pub_initializer(ipu_channel_address)
+    feagi_ipu_channel = FEAGI.pub_initializer(ipu_channel_address, bind=False)
     feagi_opu_channel = FEAGI.sub_initializer(opu_address=opu_channel_address)
     api_address = 'http://' + feagi_host + ':' + api_port
     stimulation_period_endpoint = FEAGI.feagi_api_burst_engine()
@@ -591,3 +593,5 @@ def main():
 
 if __name__ == '__main__':
     main()
+
+
